"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var MarkupHighLight = /** @class */ (function () {
    function MarkupHighLight(text, searchKey, caseinSensitive) {
        if (text === void 0) { text = ''; }
        if (searchKey === void 0) { searchKey = ''; }
        if (caseinSensitive === void 0) { caseinSensitive = true; }
        this._textToBeHighLighted = text;
        this._searchKey = searchKey;
        this._caseInSensitive = caseinSensitive;
    }
    MarkupHighLight.prototype.getTextToBeHighLighted = function () {
        return this._textToBeHighLighted;
    };
    MarkupHighLight.prototype.setTextToBeHighLighted = function (text) {
        this._textToBeHighLighted = text;
    };
    MarkupHighLight.prototype.getSearchKey = function () {
        return this._searchKey;
    };
    MarkupHighLight.prototype.setSearchKey = function (key) {
        this._searchKey = key;
    };
    MarkupHighLight.prototype.isCaseInSensitiveEnabled = function () {
        return this._caseInSensitive;
    };
    MarkupHighLight.prototype.toggleCaseInSensitiveEnabled = function (ignoreCase) {
        this._caseInSensitive = ignoreCase;
    };
    MarkupHighLight.prototype.getMatchingIndexes = function (tempText, searchKey) {
        var regex;
        var result;
        var indices = [];
        if (this._caseInSensitive) {
            regex = new RegExp(searchKey.toLowerCase(), 'g');
        }
        else {
            regex = new RegExp(searchKey, 'g');
        }
        var regexp = new RegExp(regex);
        if (this._caseInSensitive) {
            // tslint:disable-next-line: no-conditional-assignment
            while ((result = regexp.exec(tempText.toLowerCase()))) {
                indices.push(result.index);
            }
        }
        else {
            // tslint:disable-next-line: no-conditional-assignment
            while ((result = regexp.exec(tempText))) {
                indices.push(result.index);
            }
        }
        return indices;
    };
    MarkupHighLight.prototype.isListOfEmptyStrings = function () {
        var emptyStringList = this._textToBeHighLighted.filter(function (str) { return str === ''; });
        if (emptyStringList.length === this._textToBeHighLighted.length) {
            return true;
        }
        return false;
    };
    MarkupHighLight.prototype.getHighLightedText = function () {
        if (this._searchKey === '') {
            return this._textToBeHighLighted;
        }
        if (this._textToBeHighLighted === '' || this._textToBeHighLighted.length === 0) {
            return '';
        }
        if (typeof this._textToBeHighLighted === 'string') {
            return this.getHighLightedString(this._textToBeHighLighted);
        }
        else {
            if (this.isListOfEmptyStrings()) {
                return this._textToBeHighLighted.map(function () { return ''; });
            }
            return this.getListOfHighLightedStrings(this._textToBeHighLighted);
        }
    };
    MarkupHighLight.prototype.getHighLightedString = function (stringToBeHighLighted) {
        var _this = this;
        var matchingIndexes = [];
        matchingIndexes = this.getMatchingIndexes(stringToBeHighLighted, this._searchKey);
        if (matchingIndexes.length === 0) {
            return stringToBeHighLighted;
        }
        var finalString = '';
        matchingIndexes.forEach(function (idx) {
            var strIdx = 0;
            while (strIdx < stringToBeHighLighted.length) {
                if (strIdx === idx) {
                    var highlightedSubString = stringToBeHighLighted.substr(strIdx, _this._searchKey.length);
                    finalString = finalString + ("<mark>" + highlightedSubString + "</mark>");
                    strIdx = strIdx + _this._searchKey.length;
                }
                else {
                    finalString = finalString + stringToBeHighLighted[strIdx];
                    strIdx++;
                }
            }
        });
        return finalString;
    };
    MarkupHighLight.prototype.getListOfHighLightedStrings = function (stringsToBeHighLighted) {
        var _this = this;
        var finalHighLightedString = [];
        stringsToBeHighLighted.forEach(function (stringToBeHighLighted) {
            finalHighLightedString.push(_this.getHighLightedString(stringToBeHighLighted));
        });
        return finalHighLightedString;
    };
    MarkupHighLight.prototype.reset = function () {
        this._textToBeHighLighted = '';
        this._searchKey = '';
        this._caseInSensitive = true;
    };
    return MarkupHighLight;
}());
exports.MarkupHighLight = MarkupHighLight;
//# sourceMappingURL=markupHighLight.js.map